
# FCP TAG

FCP =       [
            ord("f"),
            ord("c"), 
            ord("p")
            ]

# CHANNEL CONSTANTS

class Channels:
    CHANNEL_01 =      0x3e8
    CHANNEL_02 =      0x3e9
    CHANNEL_03 =      0x3ea
    CHANNEL_04 =      0x3eb
    CHANNEL_05 =      0x3ec
    CHANNEL_06 =      0x3ed
    CHANNEL_07 =      0x3ee
    CHANNEL_08 =      0x3ef
    CHANNEL_09 =      0x3f0
    CHANNEL_10 =      0x3f1